summaryrefslogtreecommitdiff
path: root/src/object.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/object.hpp')
-rw-r--r--src/object.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/object.hpp b/src/object.hpp
index b2ae334..796e7fa 100644
--- a/src/object.hpp
+++ b/src/object.hpp
@@ -32,7 +32,7 @@ namespace zmq
{
public:
- object_t (class dispatcher_t *dispatcher_, int thread_slot_);
+ object_t (class context_t *context_, int thread_slot_);
object_t (object_t *parent_);
~object_t ();
@@ -42,7 +42,7 @@ namespace zmq
protected:
// Derived object can use following functions to interact with
// global repositories. See dispatcher.hpp for function details.
int thread_slot_count ();
void create_pipe (class object_t *reader_parent_,
class object_t *writer_parent_, uint64_t hwm_, uint64_t lwm_,
@@ -87,7 +87,7 @@ namespace zmq
virtual void process_terminate_ack ();
// Pointer to the root of the infrastructure.
- class dispatcher_t *dispatcher;
+ class context_t *context;
// Slot ID of the thread the object belongs to.
int thread_slot;
@@ -42,7 +42,7 @@ namespace zmq
protected:
// Derived object can use following functions to interact with
- // global repositories. See dispatcher.hpp for function details.
+ // global repositories. See context.hpp for function details.
int thread_slot_count ();
void create_pipe (class object_t *reader_parent_,